##  Meta Model Additions
The table below lists the additions to the meta model provided by the AI governance extension.
Fact Sheet Type | Meta Model Additions
---|---
Business capability | AI Potential field in the AI Potential Assessment subsection
Application |  Fields in the AI Governance and Adoption subsection:
  * AI Usage
  * AI Risk
  * Type of Artificial Intelligence (AI)
  * Type of Artificial Intelligence (AI) Description
  * AI Potential


IT component |
  * AI Radar Classification field in the Technology Assessment subsection
  * New fact sheet subtype: AI Model (previously named “LLM”)

**Note** Before November 3, 2025, the IT component fact sheet subtype added by the AI governance extension was named “LLM.“ If you activate the extension after this date, this fact sheet subtype is added with the “AI Model“ name. To learn how to transition to the AI model subtype, see [Transitioning to the AI Model Fact Sheet Subtype](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD#loio275aaf847a441014af8a80b1657917b9__section_hh5_w1j_hhc).


